@@ -111,15 +111,15 @@ impl Map {
         let mut exits = Vec::new();
 
         // Cardinal directions
-        if self.is_exit_valid(x-1, y) { exits.push((x-1, y, 1.0)) };
+        if x > 0 && self.is_exit_valid(x-1, y) { exits.push((x-1, y, 1.0)) };
         if self.is_exit_valid(x+1, y) { exits.push((x+1, y, 1.0)) };
-        if self.is_exit_valid(x, y-1) { exits.push((x, y-1, 1.0)) };
+        if y > 0 && self.is_exit_valid(x, y-1) { exits.push((x, y-1, 1.0)) };
         if self.is_exit_valid(x, y+1) { exits.push((x, y+1, 1.0)) };
 
         // Diagonals
-        if self.is_exit_valid(x-1, y-1) { exits.push((x-1, y-1, 1.45)); }
-        if self.is_exit_valid(x+1, y-1) { exits.push((x+1, y-1, 1.45)); }
-        if self.is_exit_valid(x-1, y+1) { exits.push((x-1, y+1, 1.45)); }
+        if x > 0 && y > 0 && self.is_exit_valid(x-1, y-1) { exits.push((x-1, y-1, 1.45)); }
+        if y > 0 && self.is_exit_valid(x+1, y-1) { exits.push((x+1, y-1, 1.45)); }
+        if x > 0 && self.is_exit_valid(x-1, y+1) { exits.push((x-1, y+1, 1.45)); }
         if self.is_exit_valid(x+1, y+1) { exits.push((x+1, y+1, 1.45)); }
 
         exits
@@ -335,4 +335,18 @@ mod tests {
 
         assert_eq!(map.tiles, expected_map.tiles);
     }
+
+
+    #[test]
+    fn test_available_exists() {
+        let map_str = "
+         #########
+        #    #   #
+        ##########
+        ";
+        let map = Map::from_string(map_str);
+        let exists = map.get_available_exits(0, 0);
+
+        assert_eq!(exists.len(), 1);
+    }
 }
\ No newline at end of file
